@@ -28,7 +28,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 
 #include <gtk/gtk.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include <string.h>
 
@@ -81,6 +81,8 @@ typedef struct
     GtkWidget * menu_item;
     GtkWidget * hbox;
     GtkWidget * label_disk;
+    GtkWidget * label_mount_arrow;
+    GtkWidget * label_mount_point;
     GtkWidget * label_mount_info;
     GtkWidget * progress_bar;
     t_disk *disk; /* People, learn to program in an object-oriented way! */
